@@ -126,6 +126,14 @@ def test_predicate_only_default():
     assert baz() == "baz-default"
 
 
+def test_predicate_func_baz_name():
+    assert baz.__name__ == "baz"
+
+
+def test_predicate_func_baz_doc():
+    assert baz.__doc__ == "baz-doc"
+
+
 class TestClassA:
     @predicate()
     def foo(self):
